#include "../args.h"
#include "../cmd.h"
#include "../config.h"
#include "../error.h"
#include "../intl.h"
#include "../log.h"
#include "../util.h"
#include <unistd.h>

bool cmd_gen(ctx_t *ctx, args_t *args) {
  bool     ret = false;
  char    *dir = NULL;
  config_t cfg;

  for (size_t i = 0; i < args->count; i++) {
    if (NULL != args->list[i].name || eq(args->list[i].value, "gen"))
      continue;

    if (NULL == dir) {
      dir = args->list[i].value;
      continue;
    }

    error(_("Please specify only a signle directory for the repository"));
    return false;
  }

  if (NULL == dir) {
    error(_("Please specify a directory for the repository"));
    return false;
  }

  if (!exists(dir) || !is_dir(dir)) {
    error(_("Failed to access the directory"));
    return ret;
  }

  if (chdir(dir) < 0) {
    error(_("Failed to change directory to the specified directory"));
    return ret;
  }

  if (!config_load(ctx, &cfg, "confer.ini")) {
    error(_("Failed to load the configuration file (" FG_BOLD "confer.ini" FG_RESET "):"));
    details(errch);
    return ret;
  }

  success(_("Loaded repository configuration"));
  config_print(&cfg);

  target_t *cur     = cfg.t_first;
  int       counter = 0;

  info(_("Copying all the targets"));
  bar_init();

  while (cur && ++counter > 0) {
    if (!target_copy(cur, true)) {
      bar_free();
      error(_("Failed to copy the target:"));
      details(errch);
      goto end;
    }

    bar(counter, cfg.t_len);
    cur = cur->next;
  }

  bar_free();
  ret = true;

end:
  config_free(&cfg);
  return ret;
}
