#include <stdlib.h>
#include <string.h>
#include <strings.h>

#include "ctx.h"
#include "error.h"
#include "intl.h"
#include "util.h"

bool ctx_init(ctx_t *ctx, char *homedir) {
  bzero(ctx, sizeof(ctx_t));

  if (NULL == homedir) {
    errno = HomedirInvalid;
    error_set(_("Home directory is NULL"));
    return false;
  }

  if (!exists(homedir) && !is_dir(homedir)) {
    errno = HomedirAccessFail;
    error_set(_("Failed to access to the home directory"));
    return false;
  }

  size_t home_len = strlen(homedir);
  ctx->dir_path   = malloc(home_len + 25);
  ctx->tmp_path   = malloc(home_len + 30);
  ctx->lock_path  = malloc(home_len + 30);

  ctx->home_path = strdup(homedir);
  join(ctx->dir_path, homedir, ".local/share/confer");
  join(ctx->lock_path, ctx->dir_path, "lock");
  join(ctx->tmp_path, ctx->dir_path, "tmp");

  if (!mksubdirsp(ctx->dir_path, 0755)) {
    errno = HomedirAccessFail;
    error_set(_("Failed to access to the home directory"));
    return false;
  }

  return true;
}

void ctx_free(ctx_t *ctx) {
  free(ctx->dir_path);
  free(ctx->tmp_path);
  free(ctx->lock_path);
  free(ctx->home_path);
  bzero(ctx, sizeof(ctx_t));
}
